==> onecx-permissions-client-0.30.0-sources.jar: gen/org/tkit/onecx/permission/model/ApplicationPermissions.java <==
package gen.org.tkit.onecx.permission.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.lang.reflect.Type;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
public class ApplicationPermissions  {

    private String appId;
    private String productName;
    /**
      * resources
     **/
    private Map<String, Set<String>> permissions;

    /**
    * Get appId
    * @return appId
    **/
    @JsonProperty("appId")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public String getAppId() {
        return appId;
    }

    /**
     * Set appId
     **/
    public void setAppId(String appId) {
        this.appId = appId;
    }

    public ApplicationPermissions appId(String appId) {
        this.appId = appId;
        return this;
    }

    /**
    * Get productName
    * @return productName
    **/
    @JsonProperty("productName")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public String getProductName() {
        return productName;
    }

    /**
     * Set productName
     **/
    public void setProductName(String productName) {
        this.productName = productName;
    }

    public ApplicationPermissions productName(String productName) {
        this.productName = productName;
        return this;
    }

    /**
    * resources
    * @return permissions
    **/
    @JsonProperty("permissions")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Map<String, Set<String>> getPermissions() {
        return permissions;
    }

    /**
     * Set permissions
     **/
    public void setPermissions(Map<String, Set<String>> permissions) {
        this.permissions = permissions;
    }

    public ApplicationPermissions permissions(Map<String, Set<String>> permissions) {
        this.permissions = permissions;
        return this;
    }
    public ApplicationPermissions putPermissionsItem(String key, Set<String> permissionsItem) {
           if (this.permissions == null){
                permissions = new HashMap<>();
            }
        this.permissions.put(key, permissionsItem);
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationPermissions {\n");

        sb.append("    appId: ").append(toIndentedString(appId)).append("\n");
        sb.append("    productName: ").append(toIndentedString(productName)).append("\n");
        sb.append("    permissions: ").append(toIndentedString(permissions)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class ApplicationPermissionsQueryParam  {

        @jakarta.ws.rs.QueryParam("appId")
        private String appId;
        @jakarta.ws.rs.QueryParam("productName")
        private String productName;
        @jakarta.ws.rs.QueryParam("permissions")
        private Map<String, Set<String>> permissions = null;

        /**
        * Get appId
        * @return appId
        **/
        @JsonProperty("appId")
        public String getAppId() {
            return appId;
        }

        /**
         * Set appId
         **/
        public void setAppId(String appId) {
            this.appId = appId;
        }

        public ApplicationPermissionsQueryParam appId(String appId) {
            this.appId = appId;
            return this;
        }

        /**
        * Get productName
        * @return productName
        **/
        @JsonProperty("productName")
        public String getProductName() {
            return productName;
        }

        /**
         * Set productName
         **/
        public void setProductName(String productName) {
            this.productName = productName;
        }

        public ApplicationPermissionsQueryParam productName(String productName) {
            this.productName = productName;
            return this;
        }

        /**
        * resources
        * @return permissions
        **/
        @JsonProperty("permissions")
        public Map<String, Set<String>> getPermissions() {
            return permissions;
        }

        /**
         * Set permissions
         **/
        public void setPermissions(Map<String, Set<String>> permissions) {
            this.permissions = permissions;
        }

        public ApplicationPermissionsQueryParam permissions(Map<String, Set<String>> permissions) {
            this.permissions = permissions;
            return this;
        }
        public ApplicationPermissionsQueryParam putPermissionsItem(String key, Set<String> permissionsItem) {
            this.permissions.put(key, permissionsItem);
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class ApplicationPermissionsQueryParam {\n");

            sb.append("    appId: ").append(toIndentedString(appId)).append("\n");
            sb.append("    productName: ").append(toIndentedString(productName)).append("\n");
            sb.append("    permissions: ").append(toIndentedString(permissions)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }}

==> onecx-permissions-client-1.6.0-sources.jar: gen/org/tkit/onecx/permission/model/ApplicationPermissions.java <==
package gen.org.tkit.onecx.permission.model;


import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import com.fasterxml.jackson.annotation.JsonProperty;

@io.quarkus.runtime.annotations.RegisterForReflection
@com.fasterxml.jackson.annotation.JsonIgnoreProperties(ignoreUnknown = true)
public class ApplicationPermissions  {

    private String appId;
    private String productName;
    /**
      * resources
     **/
    private Map<String, Set<String>> permissions;

    /**
    * Get appId
    * @return appId
    **/
    @JsonProperty("appId")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public String getAppId() {
        return appId;
    }

    /**
     * Set appId
     **/
    public void setAppId(String appId) {
        this.appId = appId;
    }

    public ApplicationPermissions appId(String appId) {
        this.appId = appId;
        return this;
    }

    /**
    * Get productName
    * @return productName
    **/
    @JsonProperty("productName")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public String getProductName() {
        return productName;
    }

    /**
     * Set productName
     **/
    public void setProductName(String productName) {
        this.productName = productName;
    }

    public ApplicationPermissions productName(String productName) {
        this.productName = productName;
        return this;
    }

    /**
    * resources
    * @return permissions
    **/
    @JsonProperty("permissions")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Map<String, Set<String>> getPermissions() {
        return permissions;
    }

    /**
     * Set permissions
     **/
    public void setPermissions(Map<String, Set<String>> permissions) {
        this.permissions = permissions;
    }

    public ApplicationPermissions permissions(Map<String, Set<String>> permissions) {
        this.permissions = permissions;
        return this;
    }
    public ApplicationPermissions putPermissionsItem(String mapKey, Set<String> permissionsItem) {
           if (this.permissions == null){
                permissions = new HashMap<>();
            }
        this.permissions.put(mapKey, permissionsItem);
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationPermissions {\n");

        sb.append("    appId: ").append(toIndentedString(appId)).append("\n");
        sb.append("    productName: ").append(toIndentedString(productName)).append("\n");
        sb.append("    permissions: ").append(toIndentedString(permissions)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Compares this object to the specified object. The result is
     * {@code true} if and only if the argument is not
     * {@code null} and is a {@code ApplicationPermissions} object that
     * contains the same values as this object.
     *
     * @param   obj   the object to compare with.
     * @return  {@code true} if the objects are the same;
     *          {@code false} otherwise.
     **/
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null || getClass() != obj.getClass()) return false;

        ApplicationPermissions model = (ApplicationPermissions) obj;

        return java.util.Objects.equals(appId, model.appId) &&
        java.util.Objects.equals(productName, model.productName) &&
        java.util.Objects.equals(permissions, model.permissions);
    }

    /**
     * Returns a hash code for a {@code ApplicationPermissions}.
     *
     * @return a hash code value for a {@code ApplicationPermissions}.
     **/
    @Override
    public int hashCode() {
        return java.util.Objects.hash(appId,
        productName,
        permissions);
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @com.fasterxml.jackson.annotation.JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class ApplicationPermissionsQueryParam  {

        @jakarta.ws.rs.QueryParam("appId")
        private String appId;
        @jakarta.ws.rs.QueryParam("productName")
        private String productName;
        @jakarta.ws.rs.QueryParam("permissions")
        private Map<String, Set<String>> permissions = null;

        /**
        * Get appId
        * @return appId
        **/
        @com.fasterxml.jackson.annotation.JsonProperty("appId")
        public String getAppId() {
            return appId;
        }

        /**
         * Set appId
         **/
        public void setAppId(String appId) {
            this.appId = appId;
        }

        public ApplicationPermissionsQueryParam appId(String appId) {
            this.appId = appId;
            return this;
        }

        /**
        * Get productName
        * @return productName
        **/
        @com.fasterxml.jackson.annotation.JsonProperty("productName")
        public String getProductName() {
            return productName;
        }

        /**
         * Set productName
         **/
        public void setProductName(String productName) {
            this.productName = productName;
        }

        public ApplicationPermissionsQueryParam productName(String productName) {
            this.productName = productName;
            return this;
        }

        /**
        * resources
        * @return permissions
        **/
        @com.fasterxml.jackson.annotation.JsonProperty("permissions")
        public Map<String, Set<String>> getPermissions() {
            return permissions;
        }

        /**
         * Set permissions
         **/
        public void setPermissions(Map<String, Set<String>> permissions) {
            this.permissions = permissions;
        }

        public ApplicationPermissionsQueryParam permissions(Map<String, Set<String>> permissions) {
            this.permissions = permissions;
            return this;
        }
        public ApplicationPermissionsQueryParam putPermissionsItem(String mapKey, Set<String> permissionsItem) {
            this.permissions.put(mapKey, permissionsItem);
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class ApplicationPermissionsQueryParam {\n");

            sb.append("    appId: ").append(toIndentedString(appId)).append("\n");
            sb.append("    productName: ").append(toIndentedString(productName)).append("\n");
            sb.append("    permissions: ").append(toIndentedString(permissions)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }}
